@@ -22,10 +22,8 @@ sys.path.insert(0, os.path.abspath('./'))
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    'sphinx.ext.autodoc',
     'sphinx.ext.todo',
-    #'openstackdocstheme',
-    #'sphinx.ext.intersphinx',
+    'sphinxcontrib.apidoc',
     'oslo_config.sphinxext',
     'oslo_config.sphinxconfiggen',
 ]
@@ -44,6 +42,19 @@ bug_tag = ''
 # text edit cycles.
 # execute "export SPHINX_DEBUG=1" in your terminal to disable
 
+# sphinxcontrib.apidoc options
+apidoc_module_dir = '../../congress'
+apidoc_output_dir = 'api'
+apidoc_excluded_paths = [
+    'datalog/Python2/*',
+    'datalog/Python3/*',
+    'db/migration/alembic_migrations/*',
+    'server/*',
+    'tests/*',
+    '/dse2/disabled_test_control_bus.py']
+
+apidoc_separate_modules = True
+
 # The suffix of source filenames.
 source_suffix = '.rst'
 
@@ -64,10 +75,19 @@ add_module_names = True
 # The name of the Pygments (syntax highlighting) style to use.
 pygments_style = 'sphinx'
 
+# A list of glob-style patterns that should be excluded when looking for
+# source files. They are matched against the source file names relative to the
+# source directory, using slashes as directory separators on all platforms.
+exclude_patterns = ['api/congress.db.migration.alembic_migrations.*',
+                    'api/congress.server.*']
+
+
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['congress.']
 
-autodoc_mock_imports = ['congress.datalog.Python2', 'congress.datalog.Python3']
+autodoc_mock_imports = ['congress.datalog.Python2', 'congress.datalog.Python3',
+                        'cloudfoundryclient', 'congress.dse',
+                        'monascaclient']
 
 # -- Options for HTML output --------------------------------------------------
 
